@@ -57,7 +57,29 @@ class ClickReviewException(Exception):
 
 class ClickReview(object):
     '''This class represents click reviews'''
-    def __init__(self, fn, review_type):
+    # Convenience to break out common types of clicks (eg, app, scope,
+    # framework, click service)
+    app_allowed_peer_hooks = ["account-application",
+                              "account-service",
+                              "apparmor",
+                              "content-hub",
+                              "desktop",
+                              "push-helper",
+                              "urls",
+                              ]
+    scope_allowed_peer_hooks = ["account-application",
+                                "account-service",
+                                "apparmor",
+                                "scope",
+                                ]
+    # FIXME: when apparmor-policy is implemented, use this
+    # framework_allowed_peer_hooks = ["apparmor-policy"]
+    framework_allowed_peer_hooks = []
+    service_allowed_peer_hooks = ["bin-path",
+                                  "systemd",
+                                  ]
+
+    def __init__(self, fn, review_type, peer_hooks=None):
         self.click_package = fn
         self._check_path_exists()
         if not self.click_package.endswith(".click"):
@@ -114,6 +136,8 @@ class ClickReview(object):
 
         self.valid_frameworks = self._extract_click_frameworks()
 
+        self.peer_hooks = peer_hooks
+
     def _extract_click_frameworks(self):
         '''Extract installed click frameworks'''
         # TODO: update to use libclick API when available
@@ -216,6 +240,72 @@ class ClickReview(object):
                 error("manifest malformed: unsupported field '%s':\n%s" % (k,
                                                                            mp))
 
+    def _verify_peer_hooks(self, my_hook):
+        '''Compare manifest for required and allowed hooks'''
+        d = dict()
+        if self.peer_hooks is None:
+            return d
+
+        for app in self.manifest["hooks"]:
+            if my_hook not in self.manifest["hooks"][app]:
+                continue
+            for h in self.peer_hooks[my_hook]['required']:
+                if h == my_hook:
+                    continue
+                if h not in self.manifest["hooks"][app]:
+                    if 'missing' not in d:
+                        d['missing'] = dict()
+                    if app not in d['missing']:
+                        d['missing'][app] = []
+                    d['missing'][app].append(h)
+            for h in self.manifest["hooks"][app]:
+                if h == my_hook:
+                    continue
+                if h not in self.peer_hooks[my_hook]['allowed']:
+                    if 'disallowed' not in d:
+                        d['disallowed'] = dict()
+                    if app not in d['disallowed']:
+                        d['disallowed'][app] = []
+                    d['disallowed'][app].append(h)
+
+        return d
+
+    def check_peer_hooks(self, hooks_sublist=[]):
+        '''Check if peer hooks are valid'''
+        # Nothing to verify
+        if self.peer_hooks is None:
+            return
+
+        for hook in self.peer_hooks:
+            if len(hooks_sublist) > 0 and hook not in hooks_sublist:
+                continue
+            d = self._verify_peer_hooks(hook)
+            t = 'info'
+            n = "peer_hooks_required_%s" % hook
+            s = "OK"
+
+            if 'missing' in d and len(d['missing'].keys()) > 0:
+                t = 'error'
+                for app in d['missing']:
+                    s = "Missing required hooks for '%s': %s" % (
+                        app, ", ".join(d['missing'][app]))
+                    self._add_result(t, n, s, manual_review=True)
+            else:
+                self._add_result(t, n, s)
+
+            t = 'info'
+            n = "peer_hooks_disallowed_with_%s" % hook
+            s = "OK"
+
+            if 'disallowed' in d and len(d['disallowed'].keys()) > 0:
+                t = 'error'
+                for app in d['disallowed']:
+                    s = "Disallowed with %s (%s): %s" % (
+                        hook, app, ", ".join(d['disallowed'][app]))
+                    self._add_result(t, n, s, manual_review=True)
+            else:
+                self._add_result(t, n, s)
+
     def set_review_type(self, name):
         '''Set review name'''
         self.review_type = name
