@@ -29,7 +29,13 @@ from xdg.Exceptions import ParsingError as xdgParsingError
 class ClickReviewDesktop(ClickReview):
     '''This class represents click lint reviews'''
     def __init__(self, fn):
-        ClickReview.__init__(self, fn, "desktop")
+        peer_hooks = dict()
+        my_hook = 'desktop'
+        peer_hooks[my_hook] = dict()
+        peer_hooks[my_hook]['allowed'] = ClickReview.app_allowed_peer_hooks
+        peer_hooks[my_hook]['required'] = ["apparmor"]
+
+        ClickReview.__init__(self, fn, "desktop", peer_hooks=peer_hooks)
 
         self.desktop_files = dict()  # click-show-files and a couple tests
         self.desktop_entries = dict()
@@ -54,6 +60,15 @@ class ClickReviewDesktop(ClickReview):
                     # msg("Skipped missing desktop hook for account-qml-plugin"
                     #     " '%s'" % app)
                     continue
+                elif 'systemd' in self.manifest['hooks'][app]:
+                    # msg("Skipped missing desktop hook for systemd"
+                    #     " '%s'" % app)
+                    continue
+                elif 'framework' in self.manifest['hooks'][app]:
+                    #  TODO: verify this is the long term hook name
+                    # msg("Skipped missing desktop hook for framework"
+                    #     " '%s'" % app)
+                    continue
                 else:
                     error("could not find desktop hook for '%s'" % app)
             if not isinstance(self.manifest['hooks'][app]['desktop'], str):
@@ -327,19 +342,39 @@ class ClickReviewDesktop(ClickReview):
             s = 'OK'
             found_url_patterns = False
             found_model_search_path = False
+            found_named_webapp = False
+            urls = []
             for i in de.getExec().split():
                 if i.startswith('--webappUrlPatterns'):
                     found_url_patterns = True
                 if i.startswith('--webappModelSearchPath'):
                     found_model_search_path = True
-            if found_url_patterns and found_model_search_path:
-                t = 'error'
-                s = "should not specify --webappUrlPatterns when using " + \
-                    "--webappModelSearchPath"
-            elif not found_url_patterns and not found_model_search_path:
-                t = 'error'
-                s = "must specify one of --webappUrlPatterns or " + \
-                    "--webappModelSearchPath"
+                if i.startswith('--webapp='):
+                    found_model_search_path = True
+                if not i.startswith('--'):
+                    urls.append(i)
+            is_launching_local_app = True
+            for url in urls:
+                parts = urlsplit(url)
+                if parts.scheme in ['http', 'https']:
+                    is_launching_local_app = False
+                    break
+            if is_launching_local_app and \
+                    (found_url_patterns or found_model_search_path
+                     or found_named_webapp):
+                    t = 'error'
+                    s = "should not specify --webappUrlPatterns, " + \
+                        "--webappModelSearchPath or --webapp= when " + \
+                        "running local application"
+            elif not is_launching_local_app:
+                if found_url_patterns and found_model_search_path:
+                    t = 'error'
+                    s = "should not specify --webappUrlPatterns when using " + \
+                        "--webappModelSearchPath"
+                elif not found_url_patterns and not found_model_search_path:
+                    t = 'error'
+                    s = "must specify one of --webappUrlPatterns or " + \
+                        "--webappModelSearchPath"
             self._add_result(t, n, s)
 
     def _check_patterns(self, app, patterns, args):
