@@ -31,7 +31,7 @@ MINIMUM_CLICK_FRAMEWORK_VERSION = "0.4"
 class ClickReviewLint(ClickReview):
     '''This class represents click lint reviews'''
 
-    def __init__(self, fn):
+    def __init__(self, fn, overrides=None):
         '''Set up the class.'''
         ClickReview.__init__(self, fn, "lint")
         self.control_files = dict()
@@ -67,10 +67,17 @@ class ClickReviewLint(ClickReview):
             self.is_core_scope = (self.click_pkgname.startswith('com.ubuntu.scopes.')
                                   and self.email ==
                                   'ubuntu-devel-discuss@lists.ubuntu.com')
+            # "core snappy" is not necessarily a word we use right now, but
+            # we want to special case scopes which are written through our
+            # vetted development process.
+            self.is_core_snappy = (self.click_pkgname.startswith('com.ubuntu.snappy.')
+                                   and self.email ==
+                                   'ubuntu-devel-discuss@lists.ubuntu.com')
         else:
             self.email = None
             self.is_core_app = False
             self.is_core_scope = False
+            self.is_core_snappy = False
 
         self._list_all_compiled_binaries()
 
@@ -79,14 +86,22 @@ class ClickReviewLint(ClickReview):
                             'account-qml-plugin',
                             'account-service',
                             'apparmor',
+                            'bin-path',
                             'content-hub',
                             'desktop',
+                            'framework',
                             'pay-ui',
                             'push-helper',
                             'scope',
+                            'systemd',
                             'urls']
 
-        self.redflagged_hooks = ['pay-ui']
+        self.redflagged_hooks = ['framework',
+                                 'pay-ui',
+                                 ]
+        if overrides is None:
+            overrides = {}
+        self.overrides = overrides
 
     def _list_control_files(self):
         '''List all control files with their full path.'''
@@ -589,6 +604,9 @@ exit 1
             elif self.is_core_scope:
                 t = 'info'
                 s = "OK ('com.ubuntu.scopes' uses '%s' as email)" % self.email
+            elif self.is_core_snappy:
+                t = 'info'
+                s = "OK ('com.ubuntu.snappy' uses '%s' as email)" % self.email
             else:
                 t = 'error'
                 s = "email=%s does not match package domain=%s " \
@@ -641,9 +659,8 @@ exit 1
         '''Check framework()'''
         n = 'framework'
         l = "http://askubuntu.com/questions/460512/what-framework-should-i-use-in-my-manifest-file"
-        local_copy = os.path.join(os.path.dirname(__file__),
-                                  '../data/frameworks.json')
-        frameworks = Frameworks(local_copy)
+        framework_overrides = self.overrides.get('framework', {})
+        frameworks = Frameworks(overrides=framework_overrides)
         if self.manifest['framework'] in frameworks.AVAILABLE_FRAMEWORKS:
             t = 'info'
             s = 'OK'
