@@ -25,8 +25,18 @@ import os
 
 class ClickReviewSecurity(ClickReview):
     '''This class represents click lint reviews'''
-    def __init__(self, fn):
-        ClickReview.__init__(self, fn, "security")
+    def __init__(self, fn, overrides=None):
+        peer_hooks = dict()
+        my_hook = 'apparmor'
+        peer_hooks[my_hook] = dict()
+        # Basically, everything except frameworks
+        peer_hooks[my_hook]['allowed'] = ClickReview.app_allowed_peer_hooks + \
+            ClickReview.scope_allowed_peer_hooks + \
+            ClickReview.service_allowed_peer_hooks + \
+            ['pay-ui']
+        peer_hooks[my_hook]['required'] = []
+
+        ClickReview.__init__(self, fn, "security", peer_hooks=peer_hooks)
 
         local_copy = os.path.join(os.path.dirname(__file__),
                                   '../data/apparmor-easyprof-ubuntu.json')
@@ -78,23 +88,28 @@ class ClickReviewSecurity(ClickReview):
         # framework policy is based on major framework version. In 13.10, there
         # was only 'ubuntu-sdk-13.10', but in 14.04, there will be several,
         # like 'ubuntu-sdk-14.04-html5', 'ubuntu-sdk-14.04-platform', etc
-        self.major_framework_policy = {'ubuntu-sdk-13.10': 1.0,
-                                       'ubuntu-sdk-14.04': 1.1,
-                                       'ubuntu-sdk-14.10': 1.2,
-                                       }
+        self.major_framework_policy = {
+            'ubuntu-sdk-13.10': {
+                'policy_version': 1.0,
+            },
+            'ubuntu-sdk-14.04': {
+                'policy_version': 1.1,
+            },
+            'ubuntu-sdk-14.10': {
+                'policy_version': 1.2,
+            },
+        }
+        if overrides is None:
+            overrides = {}
+        framework_overrides = overrides.get('framework', {})
+        self._override_framework_policies(framework_overrides)
 
         self.security_manifests = dict()
         self.security_apps = []
         for app in self.manifest['hooks']:
             if 'apparmor' not in self.manifest['hooks'][app]:
-                # TODO: when we have apparmor templates for these, we want
-                #       to remove this
-                if 'account-provider' in self.manifest['hooks'][app] or \
-                   'account-qml-plugin' in self.manifest['hooks'][app]:
-                    #  msg("Skipped missing desktop hook for account-provider "
-                    #      "and account-qml-plugin '%s'" % app)
-                    continue
-                error("could not find apparmor hook for '%s'" % app)
+                #  msg("Skipped missing apparmor hook for '%s'" % app)
+                continue
             if not isinstance(self.manifest['hooks'][app]['apparmor'], str):
                 error("manifest malformed: hooks/%s/apparmor is not str" % app)
             rel_fn = self.manifest['hooks'][app]['apparmor']
@@ -102,6 +117,23 @@ class ClickReviewSecurity(ClickReview):
                 self._extract_security_manifest(app)
             self.security_apps.append(app)
 
+    def _override_framework_policies(self, overrides):
+        # override major framework policies
+        self.major_framework_policy.update(overrides)
+
+        # override apparmor policies
+        for name, data in overrides.items():
+            vendor = data.get('policy_vendor')
+            version = str(data.get('policy_version'))
+
+            if vendor not in self.aa_policy:
+                self.aa_policy[vendor] = {}
+
+            if version not in self.aa_policy[vendor]:
+                # just ensure the version is defined
+                # TODO: add support to override templates and policy groups
+                self.aa_policy[vendor][version] = {}
+
     def _extract_security_manifest(self, app):
         '''Extract security manifest and verify it has the expected
            structure'''
@@ -228,7 +260,8 @@ class ClickReviewSecurity(ClickReview):
             t = 'info'
             n = 'policy_vendor (%s)' % f
             s = "OK"
-            if 'policy_vendor' in m and m['policy_vendor'] != "ubuntu":
+            if 'policy_vendor' in m and \
+               m['policy_vendor'] not in self.aa_policy:
                 t = 'error'
                 s = "policy_vendor '%s' not found" % m['policy_vendor']
             self._add_result(t, n, s)
@@ -260,24 +293,24 @@ class ClickReviewSecurity(ClickReview):
             t = 'info'
             n = 'policy_version_is_highest (%s, %s)' % (str(highest), f)
             s = "OK"
-            if float(m['policy_version']) != highest:
+            if float(version) != highest:
                 t = 'info'
-                s = '%s != %s' % (str(m['policy_version']), str(highest))
+                s = '%s != %s' % (version, str(highest))
             self._add_result(t, n, s)
 
             t = 'info'
             n = 'policy_version_matches_framework (%s)' % (f)
             s = "OK"
             found_major = False
-            for k in self.major_framework_policy.keys():
+            for name, data in self.major_framework_policy.items():
                 # TODO: use libclick when it is available
-                if not self.manifest['framework'].startswith(k):
+                if not self.manifest['framework'].startswith(name):
                     continue
                 found_major = True
-                if m['policy_version'] != self.major_framework_policy[k]:
+                if version != str(data['policy_version']):
                     t = 'error'
-                    s = '%s != %s (%s)' % (str(m['policy_version']),
-                                           self.major_framework_policy[k],
+                    s = '%s != %s (%s)' % (version,
+                                           str(data['policy_version']),
                                            self.manifest['framework'])
             if not found_major:
                 t = 'error'
@@ -567,6 +600,9 @@ class ClickReviewSecurity(ClickReview):
             found = []
             for i in self.redflag_fields:
                 if i in m:
+                    if i == 'policy_vendor' and \
+                       m[i] in ['ubuntu', 'ubuntu-snappy']:
+                        continue
                     found.append(i)
 
             if len(found) > 0:
