@@ -713,3 +713,128 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         r = c.click_report
         expected_counts = {'info': None, 'warn': 1, 'error': 0}
         self.check_results(r, expected_counts)
+
+    def test_check_desktop_exec_webbrowser_local_app(self):
+        '''Test test_check_desktop_exec_webbrowser_local_app() local app'''
+        c = ClickReviewDesktop(self.test_name)
+        ex = "webapp-container ./www/index.html"
+        self.set_test_desktop(self.default_appname,
+                              "Exec",
+                              ex)
+        c.check_desktop_exec_webapp_args()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_desktop_exec_webbrowser_local_pattern(self):
+        '''Test test_check_desktop_exec_webbrowser_local_pattern() invalid pattern'''
+        c = ClickReviewDesktop(self.test_name)
+        ex = "webapp-container " + \
+             "--webappUrlPatterns=https?://mobile.twitter.com/* " + \
+             "./www/index.html"
+        self.set_test_desktop(self.default_appname,
+                              "Exec",
+                              ex)
+        c.check_desktop_exec_webapp_args()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_desktop_exec_webbrowser_local_webapp(self):
+        '''Test test_check_desktop_exec_webbrowser_local_webapp() invalid webapp cli'''
+        c = ClickReviewDesktop(self.test_name)
+        ex = "webapp-container " + \
+             "--webapp=DEADBEEF " + \
+             "./www/index.html"
+        self.set_test_desktop(self.default_appname,
+                              "Exec",
+                              ex)
+        c.check_desktop_exec_webapp_args()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_desktop_exec_webbrowser_local_model(self):
+        '''Test test_check_desktop_exec_webbrowser_local_model() invalid model'''
+        c = ClickReviewDesktop(self.test_name)
+        ex = "webapp-container " + \
+             "--webappModelSearchPath=. " + \
+             "./www/index.html"
+        self.set_test_desktop(self.default_appname,
+                              "Exec",
+                              ex)
+        c.check_desktop_exec_webapp_args()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_peer_hooks(self):
+        '''Test check_peer_hooks()'''
+        c = ClickReviewDesktop(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["desktop"] = "foo.desktop"
+
+        # add any required peer hooks
+        tmp["apparmor"] = "foo.apparmor"
+
+        # update the manifest and test_manifest
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        # We should end up with 2 info
+        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_peer_hooks_disallowed(self):
+        '''Test check_peer_hooks() - disallowed'''
+        c = ClickReviewDesktop(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["desktop"] = "foo.desktop"
+
+        # add any required peer hooks
+        tmp["desktop"] = "foo.desktop"
+        tmp["apparmor"] = "foo.apparmor"
+
+        # add something not allowed
+        tmp["nonexistent"] = "nonexistent-hook"
+
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_peer_hooks_required(self):
+        '''Test check_peer_hooks() - required'''
+        c = ClickReviewDesktop(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["desktop"] = "foo.desktop"
+
+        # skip adding required hooks
+
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
