@@ -18,6 +18,7 @@ from unittest.mock import patch
 
 from clickreviews.cr_lint import ClickReviewLint
 from clickreviews.cr_lint import MINIMUM_CLICK_FRAMEWORK_VERSION
+from clickreviews.frameworks import FRAMEWORKS_DATA_URL, USER_DATA_FILE
 import clickreviews.cr_tests as cr_tests
 
 
@@ -29,6 +30,21 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         cr_tests.mock_patch()
         super()
 
+    def patch_frameworks(self):
+        def _mock_frameworks(self, overrides=None):
+            self.FRAMEWORKS = {
+                'ubuntu-sdk-14.10-qml-dev2': 'available',
+                'ubuntu-sdk-13.10': 'deprecated',
+                'ubuntu-sdk-14.10-qml-dev1': 'obsolete',
+            }
+            self.AVAILABLE_FRAMEWORKS = ['ubuntu-sdk-14.10-qml-dev2']
+            self.OBSOLETE_FRAMEWORKS = ['ubuntu-sdk-14.10-qml-dev1']
+            self.DEPRECATED_FRAMEWORKS = ['ubuntu-sdk-13.10']
+        p = patch('clickreviews.frameworks.Frameworks.__init__',
+                  _mock_frameworks)
+        p.start()
+        self.addCleanup(p.stop)
+
     def test_check_architecture(self):
         '''Test check_architecture()'''
         c = ClickReviewLint(self.test_name)
@@ -554,7 +570,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
 
     def test_check_maintainer_email_special(self):
-        '''Test check_maintainer() - ubuntu-devel-discuss@lists.ubuntu.com'''
+        '''Test check_maintainer() - ubuntu-devel-discuss@ - app'''
         self.set_test_control("Package", "com.canonical.app")
         self.set_test_manifest("maintainer",
                                "Ubuntu Core Developers "
@@ -575,7 +591,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         self.check_results(r, expected=expected)
 
     def test_check_maintainer_email_special2(self):
-        '''Test check_maintainer() - ubuntu-devel-discuss@lists.ubuntu.com'''
+        '''Test check_maintainer() - ubuntu-devel-discuss@ - scope'''
         self.set_test_control("Package", "com.ubuntu.scopes.youtube")
         self.set_test_manifest("maintainer",
                                "Ubuntu Core Developers "
@@ -595,6 +611,27 @@ class TestClickReviewLint(cr_tests.TestClickReview):
              "'ubuntu-devel-discuss@lists.ubuntu.com' as email)"}
         self.check_results(r, expected=expected)
 
+    def test_check_maintainer_email_special3(self):
+        '''Test check_maintainer() - ubuntu-devel-discuss@ - snappy'''
+        self.set_test_control("Package", "com.ubuntu.snappy.foo")
+        self.set_test_manifest("maintainer",
+                               "Ubuntu Core Developers "
+                               "<ubuntu-devel-discuss@lists.ubuntu.com>")
+        c = ClickReviewLint(self.test_name)
+        c.check_maintainer()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+        expected = dict()
+        expected['info'] = dict()
+        expected['warn'] = dict()
+        expected['error'] = dict()
+        expected['info']['lint_maintainer_domain'] = \
+            {"text": "OK ('com.ubuntu.snappy' uses "
+             "'ubuntu-devel-discuss@lists.ubuntu.com' as email)"}
+        self.check_results(r, expected=expected)
+
     def test_check_icon(self):
         '''Test check_icon()'''
         self.set_test_manifest("icon", "someicon")
@@ -682,6 +719,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
 
     def test_check_framework(self):
         '''Test check_framework()'''
+        self.patch_frameworks()
         self.set_test_manifest("framework", "ubuntu-sdk-14.10-qml-dev2")
         c = ClickReviewLint(self.test_name)
         c.check_framework()
@@ -689,8 +727,25 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    @patch('clickreviews.remote.read_cr_file')
+    def test_check_framework_fetches_remote_data(self, mock_read_cr_file):
+        '''Test check_framework()'''
+        mock_read_cr_file.return_value = {
+            'ubuntu-sdk-14.10-qml-dev2': 'available',
+        }
+        self.set_test_manifest("framework", "ubuntu-sdk-14.10-qml-dev2")
+        c = ClickReviewLint(self.test_name)
+        c.check_framework()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+        # ensure no local fn is provided when reading frameworks
+        mock_read_cr_file.assert_called_once_with(
+            USER_DATA_FILE, FRAMEWORKS_DATA_URL)
+
     def test_check_framework_bad(self):
         '''Test check_framework() - bad'''
+        self.patch_frameworks()
         self.set_test_manifest("framework", "nonexistent")
         c = ClickReviewLint(self.test_name)
         c.check_framework()
@@ -700,6 +755,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
 
     def test_check_framework_deprecated(self):
         '''Test check_framework() - deprecated'''
+        self.patch_frameworks()
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
         c = ClickReviewLint(self.test_name)
         c.check_framework()
@@ -709,6 +765,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
 
     def test_check_framework_obsolete(self):
         '''Test check_framework() - obsolete'''
+        self.patch_frameworks()
         self.set_test_manifest("framework", "ubuntu-sdk-14.10-qml-dev1")
         c = ClickReviewLint(self.test_name)
         c.check_framework()
@@ -716,6 +773,34 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    @patch('clickreviews.remote.read_cr_file')
+    def test_check_framework_with_overrides(self, mock_read_cr_file):
+        '''Test check_framework() - using overrides'''
+        mock_read_cr_file.return_value = {
+            'ubuntu-sdk-14.10-qml-dev2': 'available',
+        }
+        self.set_test_manifest("framework", "nonexistent")
+        overrides = {'framework': {'nonexistent': {'state': 'available'}}}
+        c = ClickReviewLint(self.test_name, overrides=overrides)
+        c.check_framework()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    @patch('clickreviews.remote.read_cr_file')
+    def test_check_framework_with_malformed_overrides(self, mock_read_cr_file):
+        '''Test check_framework() - using overrides'''
+        mock_read_cr_file.return_value = {
+            'ubuntu-sdk-14.10-qml-dev2': 'available',
+        }
+        self.set_test_manifest("framework", "nonexistent")
+        overrides = {'nonexistent': {'state': 'available'}}
+        c = ClickReviewLint(self.test_name, overrides=overrides)
+        c.check_framework()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
     def test_check_hooks(self):
         '''Test check_hooks()'''
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
