@@ -136,7 +136,7 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
             policy_version = 0
             for k in tmp.major_framework_policy.keys():
                 if f.startswith(k):
-                    policy_version = tmp.major_framework_policy[k]
+                    policy_version = tmp.major_framework_policy[k]['policy_version']
             self.set_test_security_manifest(self.default_appname,
                                             "policy_version",
                                             policy_version)
@@ -209,6 +209,45 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
             {"text": "Invalid framework 'nonexistent'"}
         self.check_results(report, expected=expected)
 
+    def _test_check_policy_version_framework_with_overrides(self, overrides):
+        '''Test check_policy_version() - override framework (nonexistent)'''
+        self.set_test_manifest("framework", "nonexistent")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_version", 1.3)
+        c = ClickReviewSecurity(self.test_name, overrides=overrides)
+        c.check_policy_version()
+        report = c.click_report
+
+        expected_counts = {'info': 3, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_policy_version_framework_overrides_version_float(self):
+        overrides = {'framework': {'nonexistent': {'state': 'available',
+                                                   'policy_vendor': 'ubuntu',
+                                                   'policy_version': 1.3}}}
+        self._test_check_policy_version_framework_with_overrides(overrides)
+
+    def test_check_policy_version_framework_overrides_version_string(self):
+        overrides = {'framework': {'nonexistent': {'state': 'available',
+                                                   'policy_vendor': 'ubuntu',
+                                                   'policy_version': '1.3'}}}
+        self._test_check_policy_version_framework_with_overrides(overrides)
+
+    def test_check_policy_version_framework_with_malformed_overrides(self):
+        '''Test check_policy_version() - incorrectly override framework'''
+        self.set_test_manifest("framework", "nonexistent")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_version", 1.3)
+        overrides = {'nonexistent': {'state': 'available',
+                                     'policy_vendor': 'ubuntu',
+                                     'policy_version': 1.3}}
+        c = ClickReviewSecurity(self.test_name, overrides=overrides)
+        c.check_policy_version()
+        report = c.click_report
+
+        expected_counts = {'info': 1, 'warn': 0, 'error': 2}
+        self.check_results(report, expected_counts)
+
     def test_check_policy_vendor_unspecified(self):
         '''Test check_policy_vendor() - unspecified'''
         c = ClickReviewSecurity(self.test_name)
@@ -227,6 +266,18 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
 
+    def test_check_policy_vendor_ubuntu_snappy(self):
+        '''Test check_policy_vendor() - ubuntu-snappy'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "ubuntu-snappy")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_version", 1.3)
+        c.check_policy_vendor()
+        report = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
     def test_check_policy_vendor_nonexistent(self):
         '''Test check_policy_vendor() - nonexistent'''
         c = ClickReviewSecurity(self.test_name)
@@ -728,3 +779,126 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
         report = c.click_report
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(report, expected_counts)
+
+    def test_check_peer_hooks(self):
+        '''Test check_peer_hooks()'''
+        c = ClickReviewSecurity(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["apparmor"] = "foo.apparmor"
+
+        # update the manifest and test_manifest
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        # We should end up with 2 info
+        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_peer_hooks_disallowed(self):
+        '''Test check_peer_hooks() - disallowed'''
+        c = ClickReviewSecurity(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["apparmor"] = "foo.apparmor"
+
+        # add something not allowed
+        tmp["framework"] = "foo.framework"
+
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_redflag_policy_vendor_ubuntu(self):
+        '''Test check_redflag() - policy_vendor - ubuntu'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "ubuntu")
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_policy_vendor_ubuntu_snappy(self):
+        '''Test check_redflag() - policy_vendor - ubuntu-snappy'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "ubuntu-snappy")
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_policy_vendor_notubuntu(self):
+        '''Test check_redflag() - policy_vendor - notubuntu'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "notubuntu")
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_abstractions(self):
+        '''Test check_redflag() - abstractions'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "abstractions", ["python"])
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_binary(self):
+        '''Test check_redflag() - binary'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "binary", "/bin/foo")
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_read_path(self):
+        '''Test check_redflag() - read_path'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "read_path", ["/"])
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_template_variables(self):
+        '''Test check_redflag() - template_variables'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "template_variables", {"FOO": "bar"})
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
+
+    def test_check_redflag_write_path(self):
+        '''Test check_redflag() - write_path'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "write_path", ["/"])
+        c.check_redflag()
+        report = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
